
@import "mixins";

.navbar-fixed-top {

}

.WP {
  // Profile avatar
  &-profile-avatar {
    @include circle-image(100px, none, none)
  }
  &-profile-avatar-50 {
    @include circle-image(50px, none, none)
  }
  &-profile-avatar-100 {
    @include circle-image(100px, none, none)
  }
  &-profile-avatar-150 {
    @include circle-image(150px, none, none)
  }
  &-profile-avatar-200 {
    @include circle-image(200px, none, none)
  }

  &-share-buttons {
    font-size: 20px;
    a {
      text-decoration: none !important;
    }
  }

}



