img.responsive {
  display: inline-block;
  height: auto;
  max-width: 100%; }

.WP-profile-avatar {
  border: solid 2px none;
  border-left-color: none;
  padding: 2px;
  display: inline-block;
  border-radius: 50%;
  position: relative;
  transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -webkit-transform: rotate(45deg); }
  .WP-profile-avatar img {
    width: 100px;
    height: 100px;
    display: block;
    border-radius: 50%;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar:before, .WP-profile-avatar:after {
    content: '';
    position: absolute;
    background: #fff;
    z-index: -1;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar:before {
    height: 4px;
    top: 50%;
    left: 2px;
    right: -5px;
    margin-top: -2px; }
  .WP-profile-avatar:after {
    width: 4px;
    left: 50%;
    top: 2px;
    bottom: -5px;
    margin-left: -2px; }
.WP-profile-avatar-50 {
  border: solid 2px none;
  border-left-color: none;
  padding: 2px;
  display: inline-block;
  border-radius: 50%;
  position: relative;
  transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -webkit-transform: rotate(45deg); }
  .WP-profile-avatar-50 img {
    width: 50px;
    height: 50px;
    display: block;
    border-radius: 50%;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar-50:before, .WP-profile-avatar-50:after {
    content: '';
    position: absolute;
    background: #fff;
    z-index: -1;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar-50:before {
    height: 4px;
    top: 50%;
    left: 2px;
    right: -5px;
    margin-top: -2px; }
  .WP-profile-avatar-50:after {
    width: 4px;
    left: 50%;
    top: 2px;
    bottom: -5px;
    margin-left: -2px; }
.WP-profile-avatar-100 {
  border: solid 2px none;
  border-left-color: none;
  padding: 2px;
  display: inline-block;
  border-radius: 50%;
  position: relative;
  transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -webkit-transform: rotate(45deg); }
  .WP-profile-avatar-100 img {
    width: 100px;
    height: 100px;
    display: block;
    border-radius: 50%;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar-100:before, .WP-profile-avatar-100:after {
    content: '';
    position: absolute;
    background: #fff;
    z-index: -1;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar-100:before {
    height: 4px;
    top: 50%;
    left: 2px;
    right: -5px;
    margin-top: -2px; }
  .WP-profile-avatar-100:after {
    width: 4px;
    left: 50%;
    top: 2px;
    bottom: -5px;
    margin-left: -2px; }
.WP-profile-avatar-150 {
  border: solid 2px none;
  border-left-color: none;
  padding: 2px;
  display: inline-block;
  border-radius: 50%;
  position: relative;
  transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -webkit-transform: rotate(45deg); }
  .WP-profile-avatar-150 img {
    width: 150px;
    height: 150px;
    display: block;
    border-radius: 50%;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar-150:before, .WP-profile-avatar-150:after {
    content: '';
    position: absolute;
    background: #fff;
    z-index: -1;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar-150:before {
    height: 4px;
    top: 50%;
    left: 2px;
    right: -5px;
    margin-top: -2px; }
  .WP-profile-avatar-150:after {
    width: 4px;
    left: 50%;
    top: 2px;
    bottom: -5px;
    margin-left: -2px; }
.WP-profile-avatar-200 {
  border: solid 2px none;
  border-left-color: none;
  padding: 2px;
  display: inline-block;
  border-radius: 50%;
  position: relative;
  transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -webkit-transform: rotate(45deg); }
  .WP-profile-avatar-200 img {
    width: 200px;
    height: 200px;
    display: block;
    border-radius: 50%;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar-200:before, .WP-profile-avatar-200:after {
    content: '';
    position: absolute;
    background: #fff;
    z-index: -1;
    transform: rotate(-45deg);
    -ms-transform: rotate(-45deg);
    -webkit-transform: rotate(-45deg); }
  .WP-profile-avatar-200:before {
    height: 4px;
    top: 50%;
    left: 2px;
    right: -5px;
    margin-top: -2px; }
  .WP-profile-avatar-200:after {
    width: 4px;
    left: 50%;
    top: 2px;
    bottom: -5px;
    margin-left: -2px; }
.WP-share-buttons {
  font-size: 20px; }
  .WP-share-buttons a {
    text-decoration: none !important; }

/*# sourceMappingURL=web-portfolio.css.map */
