{% extends "WebPortfolio/Module/Cms/Post/_layout.html" %}
{% import "WebPortfolio/macros/base.html" as wp with context %}

{%  block post_content %}
    <h1>Archive</h1>

    {% for post in posts %}
        <li>{{ post.published_at | datetime("%B %Y") }}</li>
    {% endfor %}

{%  endblock %}