{#
WebPortfolio

This your base layout
 #}

{% import "WebPortfolio/macros/base.html" as  wp with context %}
{% import "WebPortfolio/macros/navbar.html" as navbar with context %}
{% import "WebPortfolio/macros/bootstrap.html" as bs with context %}

<!DOCTYPE html>
<html>

<head>

    {{ wp.site_header("%s - Site Name") }}

    {{ wp.css_assets("all-css") }}

    {{ bs.theme('cosmo') }}


</head>
<body>

    {{ navbar.navbar(brand="My Site Name", exclude_groups=["admin"]) }}

    <div class="container">

        <div class="row">
            <div class="col-md-12">
                {{ wp.flashed_messages() }}
            </div>
        </div>

        {# The content of the site will be included here automatically #}
        {% include __template__ %}

    </div>

    {{ wp.js_assets("all-js") }}

</body>
</html>



