{% import "WebPortfolio/macros/nav_sidebar.html" as sidebar with context %}
{% import "WebPortfolio/macros/nav_active_title.html" as active_title with context %}

<div class="container-fluid" id="{% block admin_page_id %}{% endblock %}">
    <div class="row">
        <div class="col-md-12">
            <h2>{{ active_title.parent() }} :: {{ active_title.child() }}</h2>
            <hr>
        </div>
    </div>

    <div class="row">

        <div class="col-md-2 hidden-sm hidden-xs">

            {{ sidebar.active_menu() }}

        </div>

        <div class="col-md-10 col-sm-12 col-xs-12">
            {% block admin_content %}{% endblock %}
        </div>

    </div>
</div>

{% block admin_static %}{% endblock %}


